@@ -2,7 +2,7 @@ package Web::Components::Role::TT;
 
 use 5.010001;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.6.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 use File::DataClass::Constants qw( EXCEPTION_CLASS NUL TRUE );
 use File::DataClass::Types     qw( Directory Object );
@@ -10,9 +10,17 @@ use Template;
 use Unexpected::Functions      qw( PathNotFound throw );
 use Moo::Role;
 
-requires qw( config ); # layout root skin tempdir
+requires qw( config ); # layout skin tempdir vardir
 
 # Attribute constructors
+my $_build_templates = sub {
+   my $self = shift; my $conf = $self->config; my $dir;
+
+   $conf->can( 'vardir' ) and $dir = $conf->vardir->catdir( 'templates' );
+
+   return ($dir && $dir->exists) ? $dir : $conf->root->catdir( 'templates' );
+};
+
 my $_build__templater = sub {
    my $self        =  shift;
    my $args        =  {
@@ -29,7 +37,7 @@ my $_build__templater = sub {
 
 # Public attributes
 has 'templates'  => is => 'lazy', isa => Directory, coerce => TRUE,
-   builder       => sub { $_[ 0 ]->config->root->catdir( 'templates' ) };
+   builder       => $_build_templates;
 
 # Private attributes
 has '_templater' => is => 'lazy', isa => Object, builder => $_build__templater;
@@ -137,7 +145,7 @@ Defines the following attributes;
 =item C<templates>
 
 A lazily evaluated directory which defaults to F<templates> in the configuration
-root directory. This is where the templates are stored
+F<var> directory. This is where the templates are stored
 
 The path to the template file is F<< templates/<skin>/<layout>.tt >>. The
 C<skin> and C<layout> attributes default to the values of the configuration
@@ -145,6 +153,36 @@ object
 
 =back
 
+Requires the following attributes to be provided by the consuming class;
+
+=over 3
+
+=item C<config>
+
+Requires the configuration attribute to provide the following attributes;
+
+=over 3
+
+=item C<layout>
+
+The default template name if none is provided in the stash
+
+=item C<skin>
+
+The default skin if none is provided in the stash
+
+=item C<tempdir>
+
+Path to the directory where L<Template> will store the compiled templates
+
+=item C<vardir>
+
+Path to the directory where the templates are stored
+
+=back
+
+=back
+
 =head1 Subroutines/Methods
 
 =head2 C<render_template>
